==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetI6AlreadyRegisteredTextInteractions.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetI6AlreadyRegisteredTextInteractions] (@VCC VARCHAR(50) = NULL)
AS
BEGIN
	-- CRUZAMOS LA TABLA TEMPORAL CON LAS INTERACCIONES DE LA API CON LA TABLA ASYNCINTERACTION
	SELECT DISTINCT AI.[VCC]													'vcc',
					AI.[ID]														'id',
					AI.[ID]														'InteractionId',
					AI.[Folder]													'folder',
					AI.[ExportedContent]										'exportedContent',
					AI.[Channel]												'channel',
					AI.[Campaign]												'campaign',
					AI.[StartDate]												'startDate',
					AI.[EndDate]												'endDate',
					AI.[Account]												'account',
					AI.[Initiative]												'initiative',
					AI.[ContactName]											'contactName',
					AI.[ContactAddress]											'contactAdress',
					AI.[ContactId]												'contactId',
					AI.[FirstTakedAgent]										'firstTakedAgent',
					AI.[LastTakedAgent]											'lastTakedAgent',
					AI.[TotalMessages]											'totalMessages',
					AI.[DurationTime]											'durationTime',
					AI.[AttentionTime]											'attentionTime',
					AI.[DispositionCode]										'dispositionCode',
					AI.[DispositionTreePath]									'dispositionTreePath',
					AI.[RawChar]												'rawChar',
					ISNULL(AI.[NeedI6Update], CAST(1 AS BIT))					'needI6Update'
		FROM [#InteractionsTemp] IT
		INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
			ON AI.[VCC] = IT.[VCC]
				AND  AI.[ID] = IT.[InteractionId]
				AND AI.[Folder] = IT.[Folder]
		WHERE IT.[VCC] = @VCC
	
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_6.5.0_database.tar.gz: database/mssql/procedures/GetI6AlreadyRegisteredTextInteractions.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetI6AlreadyRegisteredTextInteractions] (@VCC VARCHAR(50) = NULL)
AS
BEGIN
	-- CRUZAMOS LA TABLA TEMPORAL CON LAS INTERACCIONES DE LA API CON LA TABLA ASYNCINTERACTION
	SELECT DISTINCT AI.[VCC]													'vcc',
					AI.[ID]														'id',
					AI.[ID]														'InteractionId',
					AI.[Folder]													'folder',
					AI.[ExportedContent]										'exportedContent',
					AI.[Channel]												'channel',
					AI.[Campaign]												'campaign',
					AI.[StartDate]												'startDate',
					AI.[EndDate]												'endDate',
					AI.[Account]												'account',
					AI.[Initiative]												'initiative',
					AI.[ContactName]											'contactName',
					AI.[ContactAddress]											'contactAdress',
					AI.[ContactId]												'contactId',
					AI.[FirstTakedAgent]										'firstTakedAgent',
					AI.[LastTakedAgent]											'lastTakedAgent',
					AI.[TotalMessages]											'totalMessages',
					AI.[DurationTime]											'durationTime',
					AI.[AttentionTime]											'attentionTime',
					AI.[DispositionCode]										'dispositionCode',
					AI.[DispositionTreePath]									'dispositionTreePath',
					AI.[RawChar]												'rawChar',
					ISNULL(AI.[NeedI6Update], CAST(1 AS BIT))					'needI6Update',
					AI.[Ender]													'ender',
					AI.[ticket]													'ticket'
		FROM [#InteractionsTemp] IT
		INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
			ON AI.[VCC] = IT.[VCC]
				AND  AI.[ID] = IT.[InteractionId]
				AND AI.[Folder] = IT.[Folder]
		WHERE IT.[VCC] = @VCC
	
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
